# coding: utf-8

"""
    SmartyMeet Dev03 API REST

    No description provided (generated by Openapi Generator https://github.com/openapitools/openapi-generator)

    The version of the OpenAPI document: 1.0.1
    Contact: developer@smartymeet.com
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


from __future__ import annotations
import pprint
import re  # noqa: F401
import json

from pydantic import BaseModel, ConfigDict, Field, StrictStr, field_validator
from typing import Any, ClassVar, Dict, List, Optional
from smartytalent_client.models.timeline_attributes_schema_changes_value import TimelineAttributesSchemaChangesValue
from smartytalent_client.models.timeline_attributes_schema_summary_value import TimelineAttributesSchemaSummaryValue
from smartytalent_client.models.timeline_attributes_schema_timestamps import TimelineAttributesSchemaTimestamps
from typing import Optional, Set
from typing_extensions import Self
from pydantic_core import to_jsonable_python

class TimelineAttributesSchema(BaseModel):
    """
    TimelineAttributesSchema
    """ # noqa: E501
    entity_type: Optional[StrictStr] = Field(default=None, description="The type of entity this timeline entry refers to (e.g., \"jobs\", \"candidates\")", alias="entityType")
    entity_id: Optional[StrictStr] = Field(default=None, description="The ID of the entity this timeline entry refers to", alias="entityId")
    action: Optional[StrictStr] = Field(default=None, description="The type of change that was made")
    user_id: Optional[StrictStr] = Field(default=None, description="The ID of the user who made the change", alias="userId")
    changes: Optional[Dict[str, TimelineAttributesSchemaChangesValue]] = Field(default=None, description="A map of changed fields with old and new values")
    summary: Optional[Dict[str, TimelineAttributesSchemaSummaryValue]] = Field(default=None, description="AI-generated summary of the change, keyed by locale (e.g., \"en-US\")")
    timestamps: Optional[TimelineAttributesSchemaTimestamps] = None
    __properties: ClassVar[List[str]] = ["entityType", "entityId", "action", "userId", "changes", "summary", "timestamps"]

    @field_validator('entity_type')
    def entity_type_validate_enum(cls, value):
        """Validates the enum"""
        if value is None:
            return value

        if value not in set(['jobs', 'candidates']):
            raise ValueError("must be one of enum values ('jobs', 'candidates')")
        return value

    @field_validator('action')
    def action_validate_enum(cls, value):
        """Validates the enum"""
        if value is None:
            return value

        if value not in set(['INSERT', 'MODIFY', 'REMOVE']):
            raise ValueError("must be one of enum values ('INSERT', 'MODIFY', 'REMOVE')")
        return value

    model_config = ConfigDict(
        validate_by_name=True,
        validate_by_alias=True,
        validate_assignment=True,
        protected_namespaces=(),
    )


    def to_str(self) -> str:
        """Returns the string representation of the model using alias"""
        return pprint.pformat(self.model_dump(by_alias=True))

    def to_json(self) -> str:
        """Returns the JSON representation of the model using alias"""
        return json.dumps(to_jsonable_python(self.to_dict()))

    @classmethod
    def from_json(cls, json_str: str) -> Optional[Self]:
        """Create an instance of TimelineAttributesSchema from a JSON string"""
        return cls.from_dict(json.loads(json_str))

    def to_dict(self) -> Dict[str, Any]:
        """Return the dictionary representation of the model using alias.

        This has the following differences from calling pydantic's
        `self.model_dump(by_alias=True)`:

        * `None` is only added to the output dict for nullable fields that
          were set at model initialization. Other fields with value `None`
          are ignored.
        """
        excluded_fields: Set[str] = set([
        ])

        _dict = self.model_dump(
            by_alias=True,
            exclude=excluded_fields,
            exclude_none=True,
        )
        # override the default output from pydantic by calling `to_dict()` of each value in changes (dict)
        _field_dict = {}
        if self.changes:
            for _key_changes in self.changes:
                if self.changes[_key_changes]:
                    _field_dict[_key_changes] = self.changes[_key_changes].to_dict()
            _dict['changes'] = _field_dict
        # override the default output from pydantic by calling `to_dict()` of each value in summary (dict)
        _field_dict = {}
        if self.summary:
            for _key_summary in self.summary:
                if self.summary[_key_summary]:
                    _field_dict[_key_summary] = self.summary[_key_summary].to_dict()
            _dict['summary'] = _field_dict
        # override the default output from pydantic by calling `to_dict()` of timestamps
        if self.timestamps:
            _dict['timestamps'] = self.timestamps.to_dict()
        return _dict

    @classmethod
    def from_dict(cls, obj: Optional[Dict[str, Any]]) -> Optional[Self]:
        """Create an instance of TimelineAttributesSchema from a dict"""
        if obj is None:
            return None

        if not isinstance(obj, dict):
            return cls.model_validate(obj)

        _obj = cls.model_validate({
            "entityType": obj.get("entityType"),
            "entityId": obj.get("entityId"),
            "action": obj.get("action"),
            "userId": obj.get("userId"),
            "changes": dict(
                (_k, TimelineAttributesSchemaChangesValue.from_dict(_v))
                for _k, _v in obj["changes"].items()
            )
            if obj.get("changes") is not None
            else None,
            "summary": dict(
                (_k, TimelineAttributesSchemaSummaryValue.from_dict(_v))
                for _k, _v in obj["summary"].items()
            )
            if obj.get("summary") is not None
            else None,
            "timestamps": TimelineAttributesSchemaTimestamps.from_dict(obj["timestamps"]) if obj.get("timestamps") is not None else None
        })
        return _obj





# coding: utf-8

"""
    SmartyMeet Dev03 API REST

    No description provided (generated by Openapi Generator https://github.com/openapitools/openapi-generator)

    The version of the OpenAPI document: 1.0.1
    Contact: developer@smartymeet.com
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


import unittest

from smartytalent_client.api.runs_api import RunsApi


class TestRunsApi(unittest.TestCase):
    """RunsApi unit test stubs"""

    def setUp(self) -> None:
        self.api = RunsApi()

    def tearDown(self) -> None:
        pass

    def test_cancel_run(self) -> None:
        """Test case for cancel_run

        Cancel Run
        """
        pass

    def test_create_run(self) -> None:
        """Test case for create_run

        Create Run
        """
        pass

    def test_list_runs(self) -> None:
        """Test case for list_runs

        List Runs
        """
        pass

    def test_retry_run(self) -> None:
        """Test case for retry_run

        Retry Run
        """
        pass

    def test_show_run(self) -> None:
        """Test case for show_run

        Show Run
        """
        pass


if __name__ == '__main__':
    unittest.main()



# coding: utf-8

"""
    SmartyMeet Dev03 API REST

    No description provided (generated by Openapi Generator https://github.com/openapitools/openapi-generator)

    The version of the OpenAPI document: 1.0.1
    Contact: developer@smartymeet.com
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


import unittest

from smartytalent_client.models.finder_attributes_schema import FinderAttributesSchema

class TestFinderAttributesSchema(unittest.TestCase):
    """FinderAttributesSchema unit test stubs"""

    def setUp(self):
        pass

    def tearDown(self):
        pass

    def make_instance(self, include_optional) -> FinderAttributesSchema:
        """Test FinderAttributesSchema
            include_optional is a boolean, when False only required
            params are included, when True both required and
            optional params are included """
        # uncomment below to create an instance of `FinderAttributesSchema`
        """
        model = FinderAttributesSchema()
        if include_optional:
            return FinderAttributesSchema(
                name = '',
                type = 'talents',
                query = smartytalent_client.models.query.query(),
                results = smartytalent_client.models.results.results(),
                status = 'active',
                language_code = '',
                settings = smartytalent_client.models.settings.settings(),
                source = '',
                short_code = '',
                ttl = '',
                timestamps = smartytalent_client.models.resource_timestamps_schema.ResourceTimestampsSchema(
                    created = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'), 
                    modified = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'), )
            )
        else:
            return FinderAttributesSchema(
                name = '',
                type = 'talents',
        )
        """

    def testFinderAttributesSchema(self):
        """Test FinderAttributesSchema"""
        # inst_req_only = self.make_instance(include_optional=False)
        # inst_req_and_optional = self.make_instance(include_optional=True)

if __name__ == '__main__':
    unittest.main()



# coding: utf-8

"""
    SmartyMeet Dev03 API REST

    No description provided (generated by Openapi Generator https://github.com/openapitools/openapi-generator)

    The version of the OpenAPI document: 1.0.1
    Contact: developer@smartymeet.com
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


import unittest

from smartytalent_client.models.tenant_attributes_schema import TenantAttributesSchema

class TestTenantAttributesSchema(unittest.TestCase):
    """TenantAttributesSchema unit test stubs"""

    def setUp(self):
        pass

    def tearDown(self):
        pass

    def make_instance(self, include_optional) -> TenantAttributesSchema:
        """Test TenantAttributesSchema
            include_optional is a boolean, when False only required
            params are included, when True both required and
            optional params are included """
        # uncomment below to create an instance of `TenantAttributesSchema`
        """
        model = TenantAttributesSchema()
        if include_optional:
            return TenantAttributesSchema(
                name = '',
                username = '',
                email = '01234',
                status = '',
                short_code = '',
                timestamps = smartytalent_client.models.resource_timestamps_schema.ResourceTimestampsSchema(
                    created = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'), 
                    modified = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'), ),
                phone = '',
                address = smartytalent_client.models.tenant_attributes_address_schema.TenantAttributesAddressSchema(
                    county = '', 
                    country = '', 
                    city = '', 
                    postalcode = '', 
                    street = '', ),
                settings = smartytalent_client.models.tenant_attributes_settings_schema.TenantAttributesSettingsSchema(
                    ad = smartytalent_client.models.ad.ad(), 
                    conversation = smartytalent_client.models.conversation.conversation(), 
                    report = smartytalent_client.models.report.report(), 
                    email = smartytalent_client.models.email.email(), 
                    language = '', 
                    calling = smartytalent_client.models.tenant_attributes_settings_schema_calling.TenantAttributesSettingsSchema_calling(
                        enabled = True, 
                        twilio_subaccount_sid = '', 
                        twilio_phone_number = '', 
                        twilio_phone_sid = '', 
                        provisioned_at = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'), ), ),
                plan = '0',
                active_languages = [
                    'ae-IO'
                    ],
                trial_expiry_date = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'),
                timezone = '',
                logo_url = '',
                boe_phone = '',
                boe_email = ''
            )
        else:
            return TenantAttributesSchema(
                name = '',
                email = '01234',
                plan = '0',
        )
        """

    def testTenantAttributesSchema(self):
        """Test TenantAttributesSchema"""
        # inst_req_only = self.make_instance(include_optional=False)
        # inst_req_and_optional = self.make_instance(include_optional=True)

if __name__ == '__main__':
    unittest.main()



# coding: utf-8

"""
    SmartyMeet Dev03 API REST

    No description provided (generated by Openapi Generator https://github.com/openapitools/openapi-generator)

    The version of the OpenAPI document: 1.0.1
    Contact: developer@smartymeet.com
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


import unittest

from smartytalent_client.models.list_talent_candidates_relationship import ListTalentCandidatesRelationship

class TestListTalentCandidatesRelationship(unittest.TestCase):
    """ListTalentCandidatesRelationship unit test stubs"""

    def setUp(self):
        pass

    def tearDown(self):
        pass

    def make_instance(self, include_optional) -> ListTalentCandidatesRelationship:
        """Test ListTalentCandidatesRelationship
            include_optional is a boolean, when False only required
            params are included, when True both required and
            optional params are included """
        # uncomment below to create an instance of `ListTalentCandidatesRelationship`
        """
        model = ListTalentCandidatesRelationship()
        if include_optional:
            return ListTalentCandidatesRelationship(
                data = [
                    smartytalent_client.models.candidate_relationships_schema.CandidateRelationshipsSchema(
                        job = smartytalent_client.models.candidate_relationships_job_schema.CandidateRelationshipsJobSchema(
                            data = smartytalent_client.models.candidate_relationships_job_data_schema.CandidateRelationshipsJobDataSchema(
                                type = 'jobs', 
                                id = '655cde5c9931802df628f3d2de8ca681-2', ), ), 
                        talent = smartytalent_client.models.candidate_relationships_talent_schema.CandidateRelationshipsTalentSchema(), 
                        translations = smartytalent_client.models.candidate_relationships_translations_schema.CandidateRelationshipsTranslationsSchema(), 
                        operations = smartytalent_client.models.candidate_relationships_operations_schema.CandidateRelationshipsOperationsSchema(), )
                    ],
                links = smartytalent_client.models.resource_links_schema.ResourceLinksSchema(
                    self = '', ),
                meta = {
                    'key' : ''
                    }
            )
        else:
            return ListTalentCandidatesRelationship(
        )
        """

    def testListTalentCandidatesRelationship(self):
        """Test ListTalentCandidatesRelationship"""
        # inst_req_only = self.make_instance(include_optional=False)
        # inst_req_and_optional = self.make_instance(include_optional=True)

if __name__ == '__main__':
    unittest.main()



# coding: utf-8

"""
    SmartyMeet Dev03 API REST

    No description provided (generated by Openapi Generator https://github.com/openapitools/openapi-generator)

    The version of the OpenAPI document: 1.0.1
    Contact: developer@smartymeet.com
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


import unittest

from smartytalent_client.models.job_attributes_settings_schema import JobAttributesSettingsSchema

class TestJobAttributesSettingsSchema(unittest.TestCase):
    """JobAttributesSettingsSchema unit test stubs"""

    def setUp(self):
        pass

    def tearDown(self):
        pass

    def make_instance(self, include_optional) -> JobAttributesSettingsSchema:
        """Test JobAttributesSettingsSchema
            include_optional is a boolean, when False only required
            params are included, when True both required and
            optional params are included """
        # uncomment below to create an instance of `JobAttributesSettingsSchema`
        """
        model = JobAttributesSettingsSchema()
        if include_optional:
            return JobAttributesSettingsSchema(
                conversation = smartytalent_client.models.job_attributes_settings_conversation_schema.JobAttributesSettingsConversationSchema(
                    email = smartytalent_client.models.job_attributes_settings_conversation_email_schema.JobAttributesSettingsConversationEmailSchema(
                        contact = smartytalent_client.models.job_attributes_settings_conversation_email_contact_schema.JobAttributesSettingsConversationEmailContactSchema(
                            cc = [
                                ''
                                ], 
                            bcc = [
                                ''
                                ], ), 
                        delays = smartytalent_client.models.job_attributes_settings_conversation_email_delays_schema.JobAttributesSettingsConversationEmailDelaysSchema(
                            initial = '', ), 
                        external_sender = True, 
                        is_sendable = True, ), 
                    candidate_interview = smartytalent_client.models.job_attributes_settings_conversation_candidate_interview_schema.JobAttributesSettingsConversationCandidateInterviewSchema(
                        enabled = True, 
                        questions = True, ), 
                    persona_interview = smartytalent_client.models.job_attributes_settings_conversation_persona_interview_schema.JobAttributesSettingsConversationPersonaInterviewSchema(
                        enabled = True, ), 
                    tone = '', ),
                criterias = smartytalent_client.models.job_attributes_settings_criterias_schema.JobAttributesSettingsCriteriasSchema(
                    weight = '', 
                    mandatory_criteria_rejection_rating = '', 
                    mandatory_criteria_satisfy_rating = '', ),
                operation = smartytalent_client.models.job_attributes_settings_operation_schema.JobAttributesSettingsOperationSchema(
                    change_stage = True, 
                    create_conversation_report = True, 
                    create_note = True, 
                    create_rate = True, 
                    create_tag = True, ),
                persona = smartytalent_client.models.job_attributes_settings_persona_schema.JobAttributesSettingsPersonaSchema(
                    weight = '', ),
                rating_restrictiveness = ''
            )
        else:
            return JobAttributesSettingsSchema(
        )
        """

    def testJobAttributesSettingsSchema(self):
        """Test JobAttributesSettingsSchema"""
        # inst_req_only = self.make_instance(include_optional=False)
        # inst_req_and_optional = self.make_instance(include_optional=True)

if __name__ == '__main__':
    unittest.main()



# coding: utf-8

"""
    SmartyMeet Dev03 API REST

    No description provided (generated by Openapi Generator https://github.com/openapitools/openapi-generator)

    The version of the OpenAPI document: 1.0.1
    Contact: developer@smartymeet.com
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


from __future__ import annotations
import pprint
import re  # noqa: F401
import json

from datetime import datetime
from pydantic import BaseModel, ConfigDict, Field, StrictBool, StrictStr
from typing import Any, ClassVar, Dict, List, Optional
from smartytalent_client.models.user_history_event_schema_challenge_responses_inner import UserHistoryEventSchemaChallengeResponsesInner
from smartytalent_client.models.user_history_event_schema_event_feedback import UserHistoryEventSchemaEventFeedback
from typing import Optional, Set
from typing_extensions import Self
from pydantic_core import to_jsonable_python

class UserHistoryEventSchema(BaseModel):
    """
    UserHistoryEventSchema
    """ # noqa: E501
    event_id: Optional[StrictStr] = Field(default=None, alias="eventId")
    event_type: Optional[StrictStr] = Field(default=None, alias="eventType")
    timestamp: Optional[datetime] = None
    result: Optional[StrictStr] = None
    risk_level: Optional[StrictStr] = Field(default=None, alias="riskLevel")
    risk_decision: Optional[StrictStr] = Field(default=None, alias="riskDecision")
    compromised_credentials: Optional[StrictBool] = Field(default=None, alias="compromisedCredentials")
    challenge_responses: Optional[List[UserHistoryEventSchemaChallengeResponsesInner]] = Field(default=None, alias="challengeResponses")
    ip_address: Optional[StrictStr] = Field(default=None, alias="ipAddress")
    device_name: Optional[StrictStr] = Field(default=None, alias="deviceName")
    city: Optional[StrictStr] = None
    country: Optional[StrictStr] = None
    timezone: Optional[StrictStr] = None
    new_device_used: Optional[StrictBool] = Field(default=None, alias="newDeviceUsed")
    event_feedback: Optional[UserHistoryEventSchemaEventFeedback] = Field(default=None, alias="eventFeedback")
    __properties: ClassVar[List[str]] = ["eventId", "eventType", "timestamp", "result", "riskLevel", "riskDecision", "compromisedCredentials", "challengeResponses", "ipAddress", "deviceName", "city", "country", "timezone", "newDeviceUsed", "eventFeedback"]

    model_config = ConfigDict(
        validate_by_name=True,
        validate_by_alias=True,
        validate_assignment=True,
        protected_namespaces=(),
    )


    def to_str(self) -> str:
        """Returns the string representation of the model using alias"""
        return pprint.pformat(self.model_dump(by_alias=True))

    def to_json(self) -> str:
        """Returns the JSON representation of the model using alias"""
        return json.dumps(to_jsonable_python(self.to_dict()))

    @classmethod
    def from_json(cls, json_str: str) -> Optional[Self]:
        """Create an instance of UserHistoryEventSchema from a JSON string"""
        return cls.from_dict(json.loads(json_str))

    def to_dict(self) -> Dict[str, Any]:
        """Return the dictionary representation of the model using alias.

        This has the following differences from calling pydantic's
        `self.model_dump(by_alias=True)`:

        * `None` is only added to the output dict for nullable fields that
          were set at model initialization. Other fields with value `None`
          are ignored.
        """
        excluded_fields: Set[str] = set([
        ])

        _dict = self.model_dump(
            by_alias=True,
            exclude=excluded_fields,
            exclude_none=True,
        )
        # override the default output from pydantic by calling `to_dict()` of each item in challenge_responses (list)
        _items = []
        if self.challenge_responses:
            for _item_challenge_responses in self.challenge_responses:
                if _item_challenge_responses:
                    _items.append(_item_challenge_responses.to_dict())
            _dict['challengeResponses'] = _items
        # override the default output from pydantic by calling `to_dict()` of event_feedback
        if self.event_feedback:
            _dict['eventFeedback'] = self.event_feedback.to_dict()
        # set to None if event_feedback (nullable) is None
        # and model_fields_set contains the field
        if self.event_feedback is None and "event_feedback" in self.model_fields_set:
            _dict['eventFeedback'] = None

        return _dict

    @classmethod
    def from_dict(cls, obj: Optional[Dict[str, Any]]) -> Optional[Self]:
        """Create an instance of UserHistoryEventSchema from a dict"""
        if obj is None:
            return None

        if not isinstance(obj, dict):
            return cls.model_validate(obj)

        _obj = cls.model_validate({
            "eventId": obj.get("eventId"),
            "eventType": obj.get("eventType"),
            "timestamp": obj.get("timestamp"),
            "result": obj.get("result"),
            "riskLevel": obj.get("riskLevel"),
            "riskDecision": obj.get("riskDecision"),
            "compromisedCredentials": obj.get("compromisedCredentials"),
            "challengeResponses": [UserHistoryEventSchemaChallengeResponsesInner.from_dict(_item) for _item in obj["challengeResponses"]] if obj.get("challengeResponses") is not None else None,
            "ipAddress": obj.get("ipAddress"),
            "deviceName": obj.get("deviceName"),
            "city": obj.get("city"),
            "country": obj.get("country"),
            "timezone": obj.get("timezone"),
            "newDeviceUsed": obj.get("newDeviceUsed"),
            "eventFeedback": UserHistoryEventSchemaEventFeedback.from_dict(obj["eventFeedback"]) if obj.get("eventFeedback") is not None else None
        })
        return _obj





# coding: utf-8

"""
    SmartyMeet Dev03 API REST

    No description provided (generated by Openapi Generator https://github.com/openapitools/openapi-generator)

    The version of the OpenAPI document: 1.0.1
    Contact: developer@smartymeet.com
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


from __future__ import annotations
import pprint
import re  # noqa: F401
import json

from pydantic import BaseModel, ConfigDict, Field, StrictStr, field_validator
from typing import Any, ClassVar, Dict, List, Optional
from smartytalent_client.models.resource_timestamps_schema import ResourceTimestampsSchema
from typing import Optional, Set
from typing_extensions import Self
from pydantic_core import to_jsonable_python

class FinderAttributesSchema(BaseModel):
    """
    FinderAttributesSchema
    """ # noqa: E501
    name: StrictStr = Field(description="The name of the finder search")
    type: StrictStr = Field(description="The type of search to perform")
    query: Optional[Dict[str, Any]] = Field(default=None, description="Search query parameters sent to OpenSearch. Supported keys for talent search: Semantic (full-text match) - \"search\" (multi-match across all text fields), \"name\", \"quickInsights\", \"skillsAndExpertise\", \"professionalExperience\", \"education\", \"experienceAndSeniority\", \"jobPositions\", \"keywords\", \"certifications\", \"industryExperience\", \"languagesSpoken\", \"locationPreferences\", \"personalityAndSoftSkills\", \"availability\", \"workPreferences\", \"workAuthorization\". Filters (exact match) - \"status\", \"source\", \"email\", \"gender\", \"shortCode\", \"isTalentPool\", \"relocationWillingness\", \"requiresSponsorship\", \"careerBreak\". IDs - \"jobId\", \"talentId\".")
    results: Optional[Dict[str, Any]] = Field(default=None, description="The search results returned from OpenSearch (auto-populated)")
    status: Optional[StrictStr] = Field(default=None, description="The current status of the finder")
    language_code: Optional[StrictStr] = Field(default=None, description="Language code for the finder (default en)", alias="languageCode")
    settings: Optional[Dict[str, Any]] = Field(default=None, description="Additional configuration settings")
    source: Optional[StrictStr] = Field(default=None, description="Source of the finder creation")
    short_code: Optional[StrictStr] = Field(default=None, description="Unique short identifier", alias="shortCode")
    ttl: Optional[StrictStr] = Field(default=None, description="Time-to-live expiration timestamp (ISO 8601)")
    timestamps: Optional[ResourceTimestampsSchema] = None
    __properties: ClassVar[List[str]] = ["name", "type", "query", "results", "status", "languageCode", "settings", "source", "shortCode", "ttl", "timestamps"]

    @field_validator('type')
    def type_validate_enum(cls, value):
        """Validates the enum"""
        if value not in set(['talents', 'candidates', 'jobs', 'emails', 'users', 'reports']):
            raise ValueError("must be one of enum values ('talents', 'candidates', 'jobs', 'emails', 'users', 'reports')")
        return value

    @field_validator('status')
    def status_validate_enum(cls, value):
        """Validates the enum"""
        if value is None:
            return value

        if value not in set(['active', 'pending', 'completed', 'failed', 'archived']):
            raise ValueError("must be one of enum values ('active', 'pending', 'completed', 'failed', 'archived')")
        return value

    model_config = ConfigDict(
        validate_by_name=True,
        validate_by_alias=True,
        validate_assignment=True,
        protected_namespaces=(),
    )


    def to_str(self) -> str:
        """Returns the string representation of the model using alias"""
        return pprint.pformat(self.model_dump(by_alias=True))

    def to_json(self) -> str:
        """Returns the JSON representation of the model using alias"""
        return json.dumps(to_jsonable_python(self.to_dict()))

    @classmethod
    def from_json(cls, json_str: str) -> Optional[Self]:
        """Create an instance of FinderAttributesSchema from a JSON string"""
        return cls.from_dict(json.loads(json_str))

    def to_dict(self) -> Dict[str, Any]:
        """Return the dictionary representation of the model using alias.

        This has the following differences from calling pydantic's
        `self.model_dump(by_alias=True)`:

        * `None` is only added to the output dict for nullable fields that
          were set at model initialization. Other fields with value `None`
          are ignored.
        """
        excluded_fields: Set[str] = set([
        ])

        _dict = self.model_dump(
            by_alias=True,
            exclude=excluded_fields,
            exclude_none=True,
        )
        # override the default output from pydantic by calling `to_dict()` of timestamps
        if self.timestamps:
            _dict['timestamps'] = self.timestamps.to_dict()
        # set to None if source (nullable) is None
        # and model_fields_set contains the field
        if self.source is None and "source" in self.model_fields_set:
            _dict['source'] = None

        # set to None if ttl (nullable) is None
        # and model_fields_set contains the field
        if self.ttl is None and "ttl" in self.model_fields_set:
            _dict['ttl'] = None

        return _dict

    @classmethod
    def from_dict(cls, obj: Optional[Dict[str, Any]]) -> Optional[Self]:
        """Create an instance of FinderAttributesSchema from a dict"""
        if obj is None:
            return None

        if not isinstance(obj, dict):
            return cls.model_validate(obj)

        _obj = cls.model_validate({
            "name": obj.get("name"),
            "type": obj.get("type"),
            "query": obj.get("query"),
            "results": obj.get("results"),
            "status": obj.get("status"),
            "languageCode": obj.get("languageCode"),
            "settings": obj.get("settings"),
            "source": obj.get("source"),
            "shortCode": obj.get("shortCode"),
            "ttl": obj.get("ttl"),
            "timestamps": ResourceTimestampsSchema.from_dict(obj["timestamps"]) if obj.get("timestamps") is not None else None
        })
        return _obj





# coding: utf-8

"""
    SmartyMeet Dev03 API REST

    No description provided (generated by Openapi Generator https://github.com/openapitools/openapi-generator)

    The version of the OpenAPI document: 1.0.1
    Contact: developer@smartymeet.com
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


import unittest

from smartytalent_client.models.finder_relationships_schema import FinderRelationshipsSchema

class TestFinderRelationshipsSchema(unittest.TestCase):
    """FinderRelationshipsSchema unit test stubs"""

    def setUp(self):
        pass

    def tearDown(self):
        pass

    def make_instance(self, include_optional) -> FinderRelationshipsSchema:
        """Test FinderRelationshipsSchema
            include_optional is a boolean, when False only required
            params are included, when True both required and
            optional params are included """
        # uncomment below to create an instance of `FinderRelationshipsSchema`
        """
        model = FinderRelationshipsSchema()
        if include_optional:
            return FinderRelationshipsSchema(
                jobs = smartytalent_client.models.finder_relationships_jobs_schema.FinderRelationshipsJobsSchema(
                    data = [
                        smartytalent_client.models.finder_relationships_jobs_data_schema.FinderRelationshipsJobsDataSchema(
                            type = 'jobs', 
                            id = '655cde5c9931802df628f3d2de8ca681-2', )
                        ], ),
                users = smartytalent_client.models.finder_relationships_users_schema.FinderRelationshipsUsersSchema(
                    data = [
                        smartytalent_client.models.finder_relationships_users_data_schema.FinderRelationshipsUsersDataSchema(
                            type = 'users', 
                            id = '655cde5c9931802df628f3d2de8ca681-2', )
                        ], ),
                talents = smartytalent_client.models.finder_relationships_talents_schema.FinderRelationshipsTalentsSchema(
                    data = [
                        smartytalent_client.models.finder_relationships_talents_data_schema.FinderRelationshipsTalentsDataSchema(
                            type = 'talents', 
                            id = '655cde5c9931802df628f3d2de8ca681-2', )
                        ], ),
                candidates = smartytalent_client.models.finder_relationships_candidates_schema.FinderRelationshipsCandidatesSchema(
                    data = [
                        smartytalent_client.models.finder_relationships_candidates_data_schema.FinderRelationshipsCandidatesDataSchema(
                            type = 'candidates', 
                            id = '655cde5c9931802df628f3d2de8ca681-2', )
                        ], )
            )
        else:
            return FinderRelationshipsSchema(
        )
        """

    def testFinderRelationshipsSchema(self):
        """Test FinderRelationshipsSchema"""
        # inst_req_only = self.make_instance(include_optional=False)
        # inst_req_and_optional = self.make_instance(include_optional=True)

if __name__ == '__main__':
    unittest.main()



# coding: utf-8

"""
    SmartyMeet Dev03 API REST

    No description provided (generated by Openapi Generator https://github.com/openapitools/openapi-generator)

    The version of the OpenAPI document: 1.0.1
    Contact: developer@smartymeet.com
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


import unittest

from smartytalent_client.models.create_notification_request_body_data import CreateNotificationRequestBodyData

class TestCreateNotificationRequestBodyData(unittest.TestCase):
    """CreateNotificationRequestBodyData unit test stubs"""

    def setUp(self):
        pass

    def tearDown(self):
        pass

    def make_instance(self, include_optional) -> CreateNotificationRequestBodyData:
        """Test CreateNotificationRequestBodyData
            include_optional is a boolean, when False only required
            params are included, when True both required and
            optional params are included """
        # uncomment below to create an instance of `CreateNotificationRequestBodyData`
        """
        model = CreateNotificationRequestBodyData()
        if include_optional:
            return CreateNotificationRequestBodyData(
                type = 'notifications',
                attributes = smartytalent_client.models.notification_attributes_schema.NotificationAttributesSchema(
                    title = '', 
                    subtitle = '', 
                    category = 'general', 
                    status = 'unread', 
                    avatar_icon = '', 
                    avatar_text = '', 
                    avatar_image = '', 
                    avatar_color = 'primary', 
                    created = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'), 
                    modified = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'), ),
                relationships = smartytalent_client.models.notification_relationships_schema.NotificationRelationshipsSchema(
                    users = smartytalent_client.models.notification_relationships_schema_users.NotificationRelationshipsSchema_users(
                        data = [
                            smartytalent_client.models.notification_relationships_schema_users_data_inner.NotificationRelationshipsSchema_users_data_inner(
                                type = 'users', 
                                id = '655cde5c9931802df628f3d2de8ca681-1', )
                            ], ), )
            )
        else:
            return CreateNotificationRequestBodyData(
                type = 'notifications',
                attributes = smartytalent_client.models.notification_attributes_schema.NotificationAttributesSchema(
                    title = '', 
                    subtitle = '', 
                    category = 'general', 
                    status = 'unread', 
                    avatar_icon = '', 
                    avatar_text = '', 
                    avatar_image = '', 
                    avatar_color = 'primary', 
                    created = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'), 
                    modified = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'), ),
        )
        """

    def testCreateNotificationRequestBodyData(self):
        """Test CreateNotificationRequestBodyData"""
        # inst_req_only = self.make_instance(include_optional=False)
        # inst_req_and_optional = self.make_instance(include_optional=True)

if __name__ == '__main__':
    unittest.main()



# coding: utf-8

"""
    SmartyMeet Dev03 API REST

    No description provided (generated by Openapi Generator https://github.com/openapitools/openapi-generator)

    The version of the OpenAPI document: 1.0.1
    Contact: developer@smartymeet.com
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


import unittest

from smartytalent_client.api.candidates_api import CandidatesApi


class TestCandidatesApi(unittest.TestCase):
    """CandidatesApi unit test stubs"""

    def setUp(self) -> None:
        self.api = CandidatesApi()

    def tearDown(self) -> None:
        pass

    def test_candidate_jobs_options(self) -> None:
        """Test case for candidate_jobs_options

        Candidate Jobs Options
        """
        pass

    def test_candidate_jobs_relationships_options(self) -> None:
        """Test case for candidate_jobs_relationships_options

        Candidate Jobs Relationships Options
        """
        pass

    def test_candidate_options(self) -> None:
        """Test case for candidate_options

        Candidate Options
        """
        pass

    def test_candidate_talents_options(self) -> None:
        """Test case for candidate_talents_options

        Candidate Talents Options
        """
        pass

    def test_candidate_talents_relationships_options(self) -> None:
        """Test case for candidate_talents_relationships_options

        Candidate Talents Relationships Options
        """
        pass

    def test_candidates_options(self) -> None:
        """Test case for candidates_options

        Candidates Options
        """
        pass

    def test_create_candidate(self) -> None:
        """Test case for create_candidate

        Create Candidate
        """
        pass

    def test_delete_candidate(self) -> None:
        """Test case for delete_candidate

        Delete Candidate
        """
        pass

    def test_list_candidate_jobs(self) -> None:
        """Test case for list_candidate_jobs

        List Candidate Jobs
        """
        pass

    def test_list_candidate_jobs_relationship(self) -> None:
        """Test case for list_candidate_jobs_relationship

        List Candidate Jobs Relationship
        """
        pass

    def test_list_candidate_talents(self) -> None:
        """Test case for list_candidate_talents

        List Candidate Talents
        """
        pass

    def test_list_candidate_talents_relationship(self) -> None:
        """Test case for list_candidate_talents_relationship

        List Candidate Talents Relationship
        """
        pass

    def test_list_candidates(self) -> None:
        """Test case for list_candidates

        List Candidates
        """
        pass

    def test_show_candidate(self) -> None:
        """Test case for show_candidate

        Show Candidate
        """
        pass

    def test_update_candidate(self) -> None:
        """Test case for update_candidate

        Update Candidate
        """
        pass


if __name__ == '__main__':
    unittest.main()



# coding: utf-8

"""
    SmartyMeet Dev03 API REST

    No description provided (generated by Openapi Generator https://github.com/openapitools/openapi-generator)

    The version of the OpenAPI document: 1.0.1
    Contact: developer@smartymeet.com
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


import unittest

from smartytalent_client.api.apikeys_api import ApikeysApi


class TestApikeysApi(unittest.TestCase):
    """ApikeysApi unit test stubs"""

    def setUp(self) -> None:
        self.api = ApikeysApi()

    def tearDown(self) -> None:
        pass

    def test_apikey_options(self) -> None:
        """Test case for apikey_options

        Apikey Options
        """
        pass

    def test_apikeys_options(self) -> None:
        """Test case for apikeys_options

        Apikeys Options
        """
        pass

    def test_create_apikey(self) -> None:
        """Test case for create_apikey

        Create Apikey
        """
        pass

    def test_delete_apikey(self) -> None:
        """Test case for delete_apikey

        Delete Apikey
        """
        pass

    def test_list_apikeys(self) -> None:
        """Test case for list_apikeys

        List Apikeys
        """
        pass

    def test_show_apikey(self) -> None:
        """Test case for show_apikey

        Show Apikey
        """
        pass

    def test_update_apikey(self) -> None:
        """Test case for update_apikey

        Update Apikey
        """
        pass


if __name__ == '__main__':
    unittest.main()



# coding: utf-8

"""
    SmartyMeet Dev03 API REST

    No description provided (generated by Openapi Generator https://github.com/openapitools/openapi-generator)

    The version of the OpenAPI document: 1.0.1
    Contact: developer@smartymeet.com
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


import unittest

from smartytalent_client.models.update_email_request_body import UpdateEmailRequestBody

class TestUpdateEmailRequestBody(unittest.TestCase):
    """UpdateEmailRequestBody unit test stubs"""

    def setUp(self):
        pass

    def tearDown(self):
        pass

    def make_instance(self, include_optional) -> UpdateEmailRequestBody:
        """Test UpdateEmailRequestBody
            include_optional is a boolean, when False only required
            params are included, when True both required and
            optional params are included """
        # uncomment below to create an instance of `UpdateEmailRequestBody`
        """
        model = UpdateEmailRequestBody()
        if include_optional:
            return UpdateEmailRequestBody(
                data = smartytalent_client.models.update_email_request_body_data.UpdateEmailRequestBodyData(
                    type = 'emails', 
                    id = '', 
                    attributes = smartytalent_client.models.email_attributes_schema.EmailAttributesSchema(
                        name = '', 
                        status = '', 
                        timestamps = smartytalent_client.models.resource_timestamps_schema.ResourceTimestampsSchema(
                            created = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'), 
                            modified = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'), ), ), )
            )
        else:
            return UpdateEmailRequestBody(
                data = smartytalent_client.models.update_email_request_body_data.UpdateEmailRequestBodyData(
                    type = 'emails', 
                    id = '', 
                    attributes = smartytalent_client.models.email_attributes_schema.EmailAttributesSchema(
                        name = '', 
                        status = '', 
                        timestamps = smartytalent_client.models.resource_timestamps_schema.ResourceTimestampsSchema(
                            created = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'), 
                            modified = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'), ), ), ),
        )
        """

    def testUpdateEmailRequestBody(self):
        """Test UpdateEmailRequestBody"""
        # inst_req_only = self.make_instance(include_optional=False)
        # inst_req_and_optional = self.make_instance(include_optional=True)

if __name__ == '__main__':
    unittest.main()



# coding: utf-8

"""
    SmartyMeet Dev03 API REST

    No description provided (generated by Openapi Generator https://github.com/openapitools/openapi-generator)

    The version of the OpenAPI document: 1.0.1
    Contact: developer@smartymeet.com
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


import unittest

from smartytalent_client.api.default_api import DefaultApi


class TestDefaultApi(unittest.TestCase):
    """DefaultApi unit test stubs"""

    def setUp(self) -> None:
        self.api = DefaultApi()

    def tearDown(self) -> None:
        pass

    def test_cors_timeline_entry(self) -> None:
        """Test case for cors_timeline_entry

        CORS support for Timeline Entry
        """
        pass

    def test_cors_timeline_rollback(self) -> None:
        """Test case for cors_timeline_rollback

        CORS support for Timeline Rollback
        """
        pass

    def test_cors_timelines(self) -> None:
        """Test case for cors_timelines

        CORS support for Timelines
        """
        pass


if __name__ == '__main__':
    unittest.main()



# coding: utf-8

"""
    SmartyMeet Dev03 API REST

    No description provided (generated by Openapi Generator https://github.com/openapitools/openapi-generator)

    The version of the OpenAPI document: 1.0.1
    Contact: developer@smartymeet.com
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


import unittest

from smartytalent_client.models.list_role_users_relationship import ListRoleUsersRelationship

class TestListRoleUsersRelationship(unittest.TestCase):
    """ListRoleUsersRelationship unit test stubs"""

    def setUp(self):
        pass

    def tearDown(self):
        pass

    def make_instance(self, include_optional) -> ListRoleUsersRelationship:
        """Test ListRoleUsersRelationship
            include_optional is a boolean, when False only required
            params are included, when True both required and
            optional params are included """
        # uncomment below to create an instance of `ListRoleUsersRelationship`
        """
        model = ListRoleUsersRelationship()
        if include_optional:
            return ListRoleUsersRelationship(
                data = [
                    smartytalent_client.models.user_relationships_schema.UserRelationshipsSchema(
                        role = smartytalent_client.models.user_relationships_role_schema.UserRelationshipsRoleSchema(
                            data = smartytalent_client.models.user_relationships_role_data_schema.UserRelationshipsRoleDataSchema(
                                type = 'roles', 
                                id = '655cde5c9931802df628f3d2de8ca681-1', ), ), 
                        jobs = smartytalent_client.models.user_relationships_jobs_schema.UserRelationshipsJobsSchema(), 
                        apikeys = smartytalent_client.models.user_relationships_apikeys_schema.UserRelationshipsApikeysSchema(), )
                    ],
                links = smartytalent_client.models.resource_links_schema.ResourceLinksSchema(
                    self = '', ),
                meta = {
                    'key' : ''
                    }
            )
        else:
            return ListRoleUsersRelationship(
        )
        """

    def testListRoleUsersRelationship(self):
        """Test ListRoleUsersRelationship"""
        # inst_req_only = self.make_instance(include_optional=False)
        # inst_req_and_optional = self.make_instance(include_optional=True)

if __name__ == '__main__':
    unittest.main()



# coding: utf-8

"""
    SmartyMeet Dev03 API REST

    No description provided (generated by Openapi Generator https://github.com/openapitools/openapi-generator)

    The version of the OpenAPI document: 1.0.1
    Contact: developer@smartymeet.com
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


import unittest

from smartytalent_client.models.update_user_request_body import UpdateUserRequestBody

class TestUpdateUserRequestBody(unittest.TestCase):
    """UpdateUserRequestBody unit test stubs"""

    def setUp(self):
        pass

    def tearDown(self):
        pass

    def make_instance(self, include_optional) -> UpdateUserRequestBody:
        """Test UpdateUserRequestBody
            include_optional is a boolean, when False only required
            params are included, when True both required and
            optional params are included """
        # uncomment below to create an instance of `UpdateUserRequestBody`
        """
        model = UpdateUserRequestBody()
        if include_optional:
            return UpdateUserRequestBody(
                data = smartytalent_client.models.update_user_request_body_data.UpdateUserRequestBodyData(
                    type = 'users', 
                    id = '', 
                    attributes = smartytalent_client.models.user_attributes_schema.UserAttributesSchema(
                        email = '', 
                        name = '', 
                        gender = '', 
                        locale = '', 
                        phone = '', 
                        is_system = True, 
                        address = { }, 
                        settings = { }, 
                        connections = { }, 
                        avatar_url = '', 
                        status = '', 
                        history_events = [
                            smartytalent_client.models.user_history_event_schema.UserHistoryEventSchema(
                                event_id = '', 
                                event_type = 'SignIn', 
                                timestamp = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'), 
                                result = 'Pass', 
                                risk_level = 'Low', 
                                risk_decision = 'NoRisk', 
                                compromised_credentials = True, 
                                challenge_responses = [
                                    smartytalent_client.models.user_history_event_schema_challenge_responses_inner.UserHistoryEventSchema_challengeResponses_inner(
                                        challenge = '', 
                                        result = '', )
                                    ], 
                                ip_address = '', 
                                device_name = '', 
                                city = '', 
                                country = '', 
                                timezone = '', 
                                new_device_used = True, 
                                event_feedback = smartytalent_client.models.user_history_event_schema_event_feedback.UserHistoryEventSchema_eventFeedback(
                                    feedback_value = '', 
                                    provider = '', ), )
                            ], 
                        timestamps = smartytalent_client.models.resource_timestamps_schema.ResourceTimestampsSchema(
                            created = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'), 
                            modified = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'), ), ), )
            )
        else:
            return UpdateUserRequestBody(
                data = smartytalent_client.models.update_user_request_body_data.UpdateUserRequestBodyData(
                    type = 'users', 
                    id = '', 
                    attributes = smartytalent_client.models.user_attributes_schema.UserAttributesSchema(
                        email = '', 
                        name = '', 
                        gender = '', 
                        locale = '', 
                        phone = '', 
                        is_system = True, 
                        address = { }, 
                        settings = { }, 
                        connections = { }, 
                        avatar_url = '', 
                        status = '', 
                        history_events = [
                            smartytalent_client.models.user_history_event_schema.UserHistoryEventSchema(
                                event_id = '', 
                                event_type = 'SignIn', 
                                timestamp = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'), 
                                result = 'Pass', 
                                risk_level = 'Low', 
                                risk_decision = 'NoRisk', 
                                compromised_credentials = True, 
                                challenge_responses = [
                                    smartytalent_client.models.user_history_event_schema_challenge_responses_inner.UserHistoryEventSchema_challengeResponses_inner(
                                        challenge = '', 
                                        result = '', )
                                    ], 
                                ip_address = '', 
                                device_name = '', 
                                city = '', 
                                country = '', 
                                timezone = '', 
                                new_device_used = True, 
                                event_feedback = smartytalent_client.models.user_history_event_schema_event_feedback.UserHistoryEventSchema_eventFeedback(
                                    feedback_value = '', 
                                    provider = '', ), )
                            ], 
                        timestamps = smartytalent_client.models.resource_timestamps_schema.ResourceTimestampsSchema(
                            created = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'), 
                            modified = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'), ), ), ),
        )
        """

    def testUpdateUserRequestBody(self):
        """Test UpdateUserRequestBody"""
        # inst_req_only = self.make_instance(include_optional=False)
        # inst_req_and_optional = self.make_instance(include_optional=True)

if __name__ == '__main__':
    unittest.main()



# coding: utf-8

"""
    SmartyMeet Dev03 API REST

    No description provided (generated by Openapi Generator https://github.com/openapitools/openapi-generator)

    The version of the OpenAPI document: 1.0.1
    Contact: developer@smartymeet.com
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


import unittest

from smartytalent_client.api.reports_api import ReportsApi


class TestReportsApi(unittest.TestCase):
    """ReportsApi unit test stubs"""

    def setUp(self) -> None:
        self.api = ReportsApi()

    def tearDown(self) -> None:
        pass

    def test_create_report(self) -> None:
        """Test case for create_report

        Create Report
        """
        pass

    def test_delete_report(self) -> None:
        """Test case for delete_report

        Delete Report
        """
        pass

    def test_list_reports(self) -> None:
        """Test case for list_reports

        List Reports
        """
        pass

    def test_report_options(self) -> None:
        """Test case for report_options

        Report Options
        """
        pass

    def test_reports_options(self) -> None:
        """Test case for reports_options

        Reports Options
        """
        pass

    def test_show_report(self) -> None:
        """Test case for show_report

        Show Report
        """
        pass

    def test_update_report(self) -> None:
        """Test case for update_report

        Update Report
        """
        pass


if __name__ == '__main__':
    unittest.main()



# coding: utf-8

"""
    SmartyMeet Dev03 API REST

    No description provided (generated by Openapi Generator https://github.com/openapitools/openapi-generator)

    The version of the OpenAPI document: 1.0.1
    Contact: developer@smartymeet.com
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


import unittest

from smartytalent_client.api.files_api import FilesApi


class TestFilesApi(unittest.TestCase):
    """FilesApi unit test stubs"""

    def setUp(self) -> None:
        self.api = FilesApi()

    def tearDown(self) -> None:
        pass

    def test_create_file(self) -> None:
        """Test case for create_file

        Create File
        """
        pass

    def test_delete_file(self) -> None:
        """Test case for delete_file

        Delete File
        """
        pass

    def test_file_options(self) -> None:
        """Test case for file_options

        File Options
        """
        pass

    def test_files_options(self) -> None:
        """Test case for files_options

        Files Options
        """
        pass

    def test_list_files(self) -> None:
        """Test case for list_files

        List Files
        """
        pass

    def test_show_file(self) -> None:
        """Test case for show_file

        Show File
        """
        pass

    def test_update_file(self) -> None:
        """Test case for update_file

        Update File
        """
        pass


if __name__ == '__main__':
    unittest.main()
